package sun.security.util;

import java.util.Iterator;
import java.util.Set;
import java.util.Collections;
import java.util.ArrayList;
import java.util.Arrays;
import java.security.AccessController;
import java.security.Security;
import java.security.PrivilegedAction;
import java.util.List;
import java.security.AlgorithmConstraints;

public abstract class AbstractAlgorithmConstraints implements AlgorithmConstraints
{
    protected final AlgorithmDecomposer decomposer;
    
    protected AbstractAlgorithmConstraints(AlgorithmDecomposer decomposer) {
        this.decomposer = decomposer;
    }
    
    static List<String> getAlgorithms(final String s) {
        String substring = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return Security.getProperty(s);
            }
        });
        String[] split = null;
        if (substring != null && !substring.isEmpty()) {
            if (substring.length() >= 2 && substring.charAt(0) == '\"' && substring.charAt(substring.length() - 1) == '\"') {
                substring = substring.substring(1, substring.length() - 1);
            }
            split = substring.split(",");
            for (int i = 0; i < split.length; ++i) {
                split[i] = split[i].trim();
            }
        }
        if (split == null) {
            return Collections.emptyList();
        }
        return new ArrayList(Arrays.asList(split));
    }
    
    static boolean checkAlgorithm(List<String> list, String anotherString, AlgorithmDecomposer algorithmDecomposer) {
        if (anotherString == null || anotherString.length() == 0) {
            throw new IllegalArgumentException("No algorithm name specified");
        }
        Set<String> decompose = null;
        for (String s : list) {
            if (s == null) {
                continue;
            }
            if (s.isEmpty()) {
                continue;
            }
            if (s.equalsIgnoreCase(anotherString)) {
                return false;
            }
            if (decompose == null) {
                decompose = algorithmDecomposer.decompose(anotherString);
            }
            Iterator<Object> iterator2 = decompose.iterator();
            while (iterator2.hasNext()) {
                if (s.equalsIgnoreCase((String)iterator2.next())) {
                    return false;
                }
                continue;
            }
        }
        return true;
    }
}
